@@ -22,7 +22,7 @@
 
 #include "config.h"
 #include "edid.h"
-#include "configmonitor.h"
+#include "output.h"
 
 #include <xcb/xcb.h>
 #include <xcb/randr.h>
@@ -33,11 +33,11 @@
 
 Q_LOGGING_CATEGORY(KSCREEN_XRANDR11, "kscreen.xrandr11")
 
-XRandR11::XRandR11(QObject* parent)
- : QObject(parent)
+XRandR11::XRandR11()
+ : KScreen::AbstractBackend()
  , m_valid(false)
  , m_x11Helper(0)
- , m_currentConfig(0)
+ , m_currentConfig(new KScreen::Config)
  , m_currentTimestamp(0)
 {
     QLoggingCategory::setFilterRules(QLatin1Literal("kscreen.xrandr11.debug = true"));
@@ -66,34 +66,39 @@ XRandR11::XRandR11(QObject* parent)
 XRandR11::~XRandR11()
 {
     closeConnection();
-    delete m_currentConfig;
     delete m_x11Helper;
 }
 
 QString XRandR11::name() const
 {
-    return "XRandR 1.1";
+    return QLatin1Literal("XRandR 1.1");
 }
 
+QString XRandR11::serviceName() const
+{
+    return QLatin1Literal("org.kde.KScreen.Backend.XRandR11");
+}
+
+
 bool XRandR11::isValid() const
 {
     return m_valid;
 }
 
-KScreen::Config* XRandR11::config() const
+KScreen::ConfigPtr XRandR11::config() const
 {
-    KScreen::Config* config = new KScreen::Config();
+    KScreen::ConfigPtr config(new KScreen::Config);
 
-    int screenId = QX11Info::appScreen();
+    const int screenId = QX11Info::appScreen();
     xcb_screen_t* xcbScreen = screen_of_display(connection(), screenId);
-    ScreenInfo info(xcbScreen->root);
-    ScreenSize size(xcbScreen->root);
+    const ScreenInfo info(xcbScreen->root);
+    const ScreenSize size(xcbScreen->root);
 
     if (info->config_timestamp == m_currentTimestamp) {
         return m_currentConfig;
     }
 
-    KScreen::Screen* screen = new KScreen::Screen();
+    KScreen::ScreenPtr screen(new KScreen::Screen);
     screen->setId(screenId);
     screen->setCurrentSize(QSize(xcbScreen->width_in_pixels, xcbScreen->height_in_pixels));
     screen->setMaxSize(QSize(size->max_width, size->max_height));
@@ -103,7 +108,7 @@ KScreen::Config* XRandR11::config() const
     config->setScreen(screen);
 
     KScreen::OutputList outputs;
-    KScreen::Output* output = new KScreen::Output();
+    KScreen::OutputPtr output(new KScreen::Output);
     output->setId(1);
 
     output->setConnected(true);
@@ -117,19 +122,17 @@ KScreen::Config* XRandR11::config() const
     outputs.insert(1, output);
     config->setOutputs(outputs);
 
-    KScreen::Mode *mode = 0;
+    KScreen::ModePtr mode;
     KScreen::ModeList modes;
 
-    int nrates;
-    uint16_t* rates;
     xcb_randr_refresh_rates_iterator_t ite =  xcb_randr_get_screen_info_rates_iterator(info.data());
     xcb_randr_screen_size_t* sizes = xcb_randr_get_screen_info_sizes(info.data());
     for (int x = 0; x < info->nSizes; x++) {
-        rates = xcb_randr_refresh_rates_rates(ite.data);
-        nrates = xcb_randr_refresh_rates_rates_length(ite.data);
+        const uint16_t* rates = xcb_randr_refresh_rates_rates(ite.data);
+        const int nrates = xcb_randr_refresh_rates_rates_length(ite.data);
 
         for (int j = 0; j < nrates; j++) {
-            mode = new KScreen::Mode();
+            mode = KScreen::ModePtr(new KScreen::Mode);
             mode->setId(QString::number(x) + "-" + QString::number(j));
             mode->setSize(QSize(sizes[x].width, sizes[x].height));
             mode->setRefreshRate((float) rates[j]);
@@ -148,45 +151,28 @@ KScreen::Config* XRandR11::config() const
     return config;
 }
 
-void XRandR11::setConfig(KScreen::Config* config) const
+void XRandR11::setConfig(const KScreen::ConfigPtr &config)
 {
-    KScreen::Output* output = config->outputs().take(1);
-    KScreen::Mode *mode = output->currentMode();
+    const KScreen::OutputPtr output = config->outputs().take(1);
+    const KScreen::ModePtr mode = output->currentMode();
 
-    int screenId = QX11Info::appScreen();
+    const int screenId = QX11Info::appScreen();
     xcb_screen_t* xcbScreen = screen_of_display(connection(), screenId);
 
-    ScreenInfo info(xcbScreen->root);
+    const ScreenInfo info(xcbScreen->root);
     xcb_generic_error_t *err;
     xcb_randr_set_screen_config_cookie_t cookie;
     xcb_randr_set_screen_config_reply_t *result;
-    int sizeId = mode->id().split("-").first().toInt();
+    const int sizeId = mode->id().split("-").first().toInt();
     cookie = xcb_randr_set_screen_config(connection(), xcbScreen->root, CurrentTime, info->config_timestamp, sizeId,
-                                       (short) output->rotation(), mode->refreshRate());
+                                         (short) output->rotation(), mode->refreshRate());
     result = xcb_randr_set_screen_config_reply(connection(), cookie, &err);
 
     delete result;
 }
 
-KScreen::Edid* XRandR11::edid(int outputId) const
-{
-    Q_UNUSED(outputId)
-    return new KScreen::Edid();
-}
-
-void XRandR11::updateConfig(KScreen::Config* config) const
-{
-    KScreen::Output* output = config->output(1);
-    KScreen::Output *current = m_currentConfig->output(1);
-    output->setCurrentModeId(current->currentModeId());
-    output->setRotation(current->rotation());
-}
-
 void XRandR11::updateConfig()
 {
-    delete m_currentConfig;
     m_currentConfig = config();
-    KScreen::ConfigMonitor::instance()->notifyUpdate();
+    Q_EMIT configChanged(m_currentConfig);
 }
-
-#include "xrandr11.moc"
